# Sensing Signal Processing (SensingSP™)

## Overview
**SensingSP™** is an open-source library designed for simulating electromagnetic sensing systems and implementing signal processing and machine learning algorithms. 

The library is developing in the **Signal Processing Applications in Radar and Communications (SPARC)** group at the **University of Luxembourg**, with support from **IEE S.A.**

---

## Features
- Simulate electromagnetic-based sensing systems.
- Implement advanced radar and signal processing algorithms.
- Leverage machine learning techniques for enhanced sensing capabilities.

---

## Installation

To install SensingSP™ and its dependencies, run the following command:

```bash
pip install sensingsp
```

## Contact

For inquiries, suggestions, or contributions, feel free to reach out:

Moein Ahmadi
Email: moein.ahmadi@uni.lu